@@ -1,5 +1,7 @@
+use serde::Serialize;
 use all4art_authservice_cqrs::query_results::LoginQueryResult;
 
+#[derive(Serialize)]
 pub struct TokenDto { 
     pub jwt: String
 }
